@@ -687,14 +687,6 @@ class SagemakerAnalytics(Magics):
         help="The IAM role to assume when connecting to a cluster in a different AWS account. This argument is not "
         "required when connecting to a cluster in the same AWS account.",
     )
-    @argument(
-        "--session-tags",
-        type=str,
-        default=None,
-        help="The session tags to set while assuming the role(specified by assumable-role-arn). It's an optional "
-        "parameter passed in json format. Error will be thrown if no assumable-role-arn is specified. An "
-        "administrator must grant you the permissions necessary to pass session tags.",
-    )
     @argument(
         "--emr-execution-role-arn",
         type=str,
@@ -755,7 +747,7 @@ def _connect_to_emr(service, operation, args, usage, kernel_name, service_logger
     try:
         _validate_emr_args(args=args, usage=usage, kernel_name=kernel_name)
         # Only create boto session if absolutely needed
-        boto_session = get_boto3_session(args.assumable_role_arn, args.session_tags)
+        boto_session = get_boto3_session(args.assumable_role_arn)
         _initiate_emr_connect(
             args=args, boto_session=boto_session, kernel_name=kernel_name
         )
