@@ -20,11 +20,17 @@ class ResourceMetadata:
             self.__boto_session = boto3.session.Session()
             self.__region_name = self.__boto_session.region_name
             if self.__region_name.startswith(ResourceMetadata.CHINA_REGION_PREFIX):
-                regional_sts_endpoint = f"https://sts.{self.__region_name}.{ResourceMetadata.CHINA_DOMAIN}"
+                regional_sts_endpoint = (
+                    f"https://sts.{self.__region_name}.{ResourceMetadata.CHINA_DOMAIN}"
+                )
             else:
-                regional_sts_endpoint = f"https://sts.{self.__region_name}.{ResourceMetadata.DOMAIN}"
+                regional_sts_endpoint = (
+                    f"https://sts.{self.__region_name}.{ResourceMetadata.DOMAIN}"
+                )
             self.__regional_sts_client = boto3.client(
-                "sts", endpoint_url=regional_sts_endpoint, region_name=self.__region_name
+                "sts",
+                endpoint_url=regional_sts_endpoint,
+                region_name=self.__region_name,
             )
             self.account_id = self.__regional_sts_client.get_caller_identity().get(
                 "Account"
